# Tavus plugin for LiveKit Agents

Support for the [Tavus](https://tavus.io/) virtual avatar.

See the [Tavus integration docs](https://docs.livekit.io/agents/models/avatar/plugins/tavus/) for more information.

## Installation

```bash
pip install livekit-plugins-tavus
```

## Pre-requisites

You'll need an API key from Tavus. It can be set as an environment variable: `TAVUS_API_KEY`
